import treemap.*;
import java.lang.Math;

int X = 1300;
int Y = 700;
int margin = 25;
int barStartPoint = 40;
int barSpacing = 15;
int barWidth = 40;

boolean showGrid=false;
boolean showBoundaries=false;
int movieCounter=1;

ArrayList movies;

Treemap moviesTreeMap;
WordMap moviesMapData;

float minGross =1500.0;
float maxGross =0.0;

PFont f1 = createFont("Arial-BoldMT", 74, true); 
PFont f2 = createFont("Arial-BoldMT", 38, true); 
PFont f3 = createFont("Arial-BoldMT", 34, true); 
PFont f4 = createFont("Arial-BoldMT", 24, true); 
PFont f5 = createFont("Arial-BoldMT", 16, true); 
PFont f6 = createFont("Arial-BoldMT", 14, true);
//PImage moviePoster;

void setup(){
  textFont(f5);
  size(X,Y);
  frameRate(30);
  colorMode(HSB,360,100,100,100);
  textAlign(LEFT, CENTER);
  smooth();
  
  movies=new ArrayList();
  loadMovieData();
  loadSPLData();
  
}

void draw(){
  background(40,0,100);
  if(showGrid)
    drawGrid();
  if(showBoundaries)
    drawBoundaries();
  insertIntoTreeMap();
  drawVisualizations();
}

void loadMovieData(){
  String data[] = loadStrings("movie.txt");
  for(int i=0;i<data.length;i++){
    String temp[] = split(data[i],"||");
    //println(data);
    Movie movie = new Movie(temp[0], temp[1], Integer.parseInt(temp[2]), Integer.parseInt(temp[3]), temp[4], Float.parseFloat(temp[5]), Float.parseFloat(temp[6]), Float.parseFloat(temp[7]), temp[8], i+1);    
    movies.add(movie);
  }
}

void loadSPLData(){
  String data[] = loadStrings("spldata.txt");
  for(int i=0;i<data.length;i++){
    Movie movie = (Movie) movies.get(i);
    int minVal = 10000;
    int maxVal = 0;
    String temp[] = split(data[i],"|");
    for(int j=0;j<temp.length;j++){
      if(Integer.parseInt(temp[j]) < minVal)
        minVal = Integer.parseInt(temp[j]);
      if(Integer.parseInt(temp[j]) > maxVal)
        maxVal = Integer.parseInt(temp[j]);
      movie.splMonthData.add(Integer.parseInt(temp[j]));
    }
    movie.splMonthData.add(minVal);
    movie.splMonthData.add(maxVal);
    //println(movie.name+movie.splMonthData);
  }
}

void insertIntoTreeMap(){
  moviesMapData = new WordMap();
  for(int i=0; i<movies.size();i++){
    Movie movie = (Movie) movies.get(i);
    if(movie.gross>maxGross)
      maxGross = movie.gross;
    if(movie.gross<minGross)
      minGross = movie.gross;
    for(int j=0; j<movie.gross; j++){
      moviesMapData.addWord(movie.name, movie);
    }
  }
  moviesMapData.finishAdd();
  moviesTreeMap = new Treemap(moviesMapData, 40, 540, 1220, 135);
  moviesTreeMap.draw();  
}

void drawVisualizations(){
  Movie movie = (Movie) movies.get(movieCounter-1);
  //println(movie.name);
  //Draw SPL Bar Graph
  int minV = (Integer) movie.splMonthData.get(movie.splMonthData.size()-2);
  int maxV = (Integer) movie.splMonthData.get(movie.splMonthData.size()-1);
  char[] monthNames = {'J','F','M','A','M','J','J','A','S','O','N','D'} ;
  for(int i=0; i<movie.splMonthData.size()-2;i++){
    int x = barStartPoint + i*(barWidth+barSpacing);
    int y = 380;
    fill(201,80,80,100);
    float heightBar = map((Integer) movie.splMonthData.get(i), minV, maxV, 20, 250);
    quad(x,y,x, y-heightBar, x+barWidth, y-heightBar, x+barWidth, y);
//    barWidth,map((Integer) movie.splMonthData.get(i), minV, maxV, 20, 100)-300); 
    fill(0);
    textFont(f6);
    textAlign(LEFT, CENTER);
    text(monthNames[i], x+15, y+10);
    //if(mouseX > x && mouseX<barWidth && mouseY < y && mouseY >(map((Integer) movie.splMonthData.get(i), minV, maxV, 20, 100)-300))
      //text((Integer) movie.splMonthData.get(i), x+15, (map((Integer) movie.splMonthData.get(i), minV, maxV, 20, 100)-320));
    textAlign(CENTER, CENTER);
    text((Integer) movie.splMonthData.get(i), x+20, y-heightBar-10);
  }
  //Add date marker
  String dateTemp[] = split(movie.date, "-");
  int monthMarker = Integer.parseInt(dateTemp[1]);
  int x = barStartPoint + (monthMarker-1)*(barWidth+barSpacing) + barWidth/2;
  int y = 380;
  
  fill(0,80,80,100) ;  
  ellipse(x,y,10,10);
  
  //add text stuff
  fill(172,16,36,100);
  textFont(f2);
  PFont dataF = loadFont("ArialNarrow-Bold-48.vlw");
  textFont(dataF, 50);
  textAlign(LEFT, CENTER);
  text(movie.genre.toUpperCase(), 40, 450);
  text("$"+Math.round(movie.budget)+"M", 300, 450);
  text("$"+Math.round(movie.gross)+"M", 500, 450);
  text(Math.round(movie.profit)+"%", 680, 450);
  
  fill(173,16,63,100);
  textFont(dataF,36);
  text("GENRE", 40, 500);
  text("BUDGET", 300, 500);
  text("GROSS", 500, 500);
  text("PROFIT", 680, 500);
  
  //textFont(f5);
  //text("What kind of story does it tell?",40, 510);
  //text("How much does it take to make?", 280, 510);
  //text("How much money did it make?", 540, 510);
  //text("% of money recovered.", 780, 510);
  
  //Embed Image
  PImage moviePoster = loadImage(movie.imageNo+".jpg");
  image(moviePoster, 900,25, 360, 380);
  
  //Movie Name
  //textFont(f3);
  fill(0,80,80,100);
  PFont movieF = loadFont("Arial-BoldMT-48.vlw");
  textFont(movieF, 36);
  textAlign(LEFT, BOTTOM);
  String[] temp = split(movie.name, "^");
  if(temp.length==2){
    text(temp[0].toUpperCase(), 40, 60);
    text(temp[1].toUpperCase(), 40, 100);
  }
  else
    text(temp[0].toUpperCase(), 40, 60);
  
  //studio name
  fill(172, 16, 36, 100);
  textAlign(RIGHT, CENTER);
  textFont(dataF, 40);
  temp = split(movie.studio, "~");
  if(temp.length==2){
    text(temp[0].toUpperCase(), 1260, 450);
    text(temp[1].toUpperCase(), 1260, 490);
  }
  else
    text(temp[0].toUpperCase(), 1260, 470);
  
  //ROTTEN TOMATOES
  textFont(f1);
  textFont(dataF, 80);
  fill(172,16,36,100);
  textAlign(LEFT,CENTER);
  text(movie.rottenTomatoes+"%", 720, 60);  
  text(movie.audienceScore+"%", 720, 260);
  
  textAlign(LEFT, CENTER);
  textFont(f3);
  textFont(dataF, 36);
  fill(173,16,63,100);
  text("ROTTEN", 720, 140);  
  text("TOMATOES", 720, 180);  
  
  text("AUDIENCE", 720, 330);  
  text("SCORE", 720, 370);
  
}

void drawGrid() {
  for(int i=0;i < X; i=i+20){
    Line temp = new Line(1);
    if((i/20)%5==0)
      temp.setColor(0,0,40,100);
    else
      temp.setColor(0,0,80,100);
    temp.setPoints(i,0, i, Y);
    temp.drawLine();
  }
  
  for(int i=0;i < Y; i=i+20){
    Line temp = new Line(1);
    if((i/20)%5==0)
      temp.setColor(0,100,0,60);
    else 
      temp.setColor(0,100,20,30);
    temp.setPoints(0,i, X, i);
    temp.drawLine();
  }  
}

void drawBoundaries(){
  Line temp1 = new Line(1);
  temp1.setColor(240,100,100,100);
  temp1.setPoints(0,25,X,25);
  temp1.drawLine();
  
  Line temp2 = new Line(1);
  temp2.setColor(240,100,100,100);
  temp2.setPoints(25,0,25,Y);
  temp2.drawLine();
  
  Line temp3 = new Line(1);
  temp3.setColor(240,100,100,100);
  temp3.setPoints(0,675,X,675);
  temp3.drawLine();
  
  Line temp4 = new Line(1);
  temp4.setColor(240,100,100,100);
  temp4.setPoints(1275,0,1275,Y);
  temp4.drawLine();
}


void keyPressed(){
  switch(key) {
    case 'G': showGrid = !showGrid;
              break;
    case 'g': showGrid = !showGrid;
              break;  
    case 'b': showBoundaries = !showBoundaries;
              break;  
  }
}
